package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.FileConstants;
import com.ynet.life.sujrb.file.NotBankOrganizationDataDetailSummary;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/NotBankOrganizationDataDetailImport.class */
public class NotBankOrganizationDataDetailImport implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public NotBankOrganizationDataDetailImport() {
    }

    public NotBankOrganizationDataDetailImport(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            NotBankOrganizationDataDetailSummary result = new NotBankOrganizationDataDetailSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                HSSFRow summaryRow = sheet.getRow(0);
                int rowIndex = 2;
                int columnNum = summaryRow.getPhysicalNumberOfCells();
                HSSFRow recordRowTemp = sheet.getRow(2);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                if (columnNum != 25) {
                    throw new TranFailException("excelError", "模板错误");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw new TranFailException("EBCB0504", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", false);
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String corName = getCellContent(recordRow, 0, true);
        String orgCode = getCellContent(recordRow, 1, true);
        String financeName = getCellContent(recordRow, 2, true);
        String secendBraUserName = getCellContent(recordRow, 3, true);
        String publishTime = getCellContent(recordRow, 4, true);
        String financeAmt = getCellContent(recordRow, 5, false);
        String financeLimit = getCellContent(recordRow, 6, true);
        String rateBegin = getCellContent(recordRow, 7, false);
        String assureWay = getCellContent(recordRow, 8, true);
        String corContactName = getCellContent(recordRow, 9, true);
        String corContactTel = getCellContent(recordRow, 10, true);
        String incomeLastYear = getCellContent(recordRow, 11, true);
        String salesThisYear = getCellContent(recordRow, 12, true);
        String applyForProduct = getCellContent(recordRow, 13, true);
        String financePurpose = getCellContent(recordRow, 14, true);
        String financeStation = getCellContent(recordRow, 15, true);
        String decomandRemark = getCellContent(recordRow, 16, true);
        String acceptTime = getCellContent(recordRow, 17, true);
        String joinProduct = getCellContent(recordRow, 18, true);
        String openCheckTime = getCellContent(recordRow, 19, true);
        String checkOperationTime = getCellContent(recordRow, 20, true);
        String creFinanceAmt = getCellContent(recordRow, 21, false);
        String financeDeadLine = getCellContent(recordRow, 22, true);
        String beginRate = getCellContent(recordRow, 23, false);
        String financeModelAudit = getCellContent(recordRow, 24, true);
        String remark = "";
        if ("".equals(corName) || corName == null) {
            remark = String.valueOf(remark) + " 企业名称为空";
        } else {
            String replace = corName.replace("(", "（").replace(")", "）");
            corName = replace;
            if (replace.length() > 50) {
                remark = String.valueOf(remark) + " 企业名称过长";
            }
        }
        if (!"".equals(orgCode) && orgCode != null && !Pattern.compile("^[a-zA-Z0-9[-]]{8,25}").matcher(orgCode).matches()) {
            remark = String.valueOf(remark) + " 统一社会信用代码不符合规则";
        }
        if ("".equals(financeName) || financeName == null) {
            remark = String.valueOf(remark) + " 金融机构为空";
        }
        if ("".equals(secendBraUserName) || secendBraUserName == null) {
            remark = String.valueOf(remark) + " 二级机构联系人姓名为空";
        }
        new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat formatYMD = new SimpleDateFormat("yyyy-MM-dd");
        formatYMD.setLenient(false);
        if ("".equals(publishTime) || publishTime == null) {
            remark = String.valueOf(remark) + " 发布时间为空";
        } else {
            try {
                formatYMD.parse(publishTime);
                publishTime = String.valueOf(publishTime.substring(0, 10)) + " 9:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused) {
                remark = String.valueOf(remark) + " 发布时间格式不正确";
            }
        }
        Pattern rex = Pattern.compile("^[1-9]{1}\\d{0,7}$");
        if ("".equals(financeAmt) || financeAmt == null) {
            remark = String.valueOf(remark) + "申请融资金额为空";
        } else if (!rex.matcher(financeAmt).matches()) {
            remark = String.valueOf(remark) + "申请融资金额不符合规则";
        }
        if ("".equals(financeLimit) || financeLimit == null) {
            remark = String.valueOf(remark) + " 融资期限为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d{0,2}$").matcher(financeLimit).matches()) {
            remark = String.valueOf(remark) + " 融资期限不符合规则";
        } else if (Integer.parseInt(financeLimit) > 360) {
            remark = String.valueOf(remark) + " 融资期限不能大于360";
        }
        Pattern rate = Pattern.compile("^\\d{1,3}(\\.\\d{1,4})?$");
        if ("".equals(rateBegin) || rateBegin == null) {
            remark = String.valueOf(remark) + " 期望利率为空";
        } else if (!rate.matcher(rateBegin).matches()) {
            remark = String.valueOf(remark) + " 期望利率不符合规则";
        }
        if ("".equals(assureWay) || assureWay == null) {
            remark = String.valueOf(remark) + " 担保方式为空";
        }
        if ("".equals(corContactName) || corContactName == null) {
            remark = String.valueOf(remark) + " 联系人为空";
        }
        Pattern tel = Pattern.compile("^((0\\d{2,3}\\-\\d{7,8})|(1[0-9]{10})|(\\d{8}))$");
        if ("".equals(corContactTel) || corContactTel == null) {
            remark = String.valueOf(remark) + " 联系电话为空";
        } else if (!tel.matcher(corContactTel).matches()) {
            remark = String.valueOf(remark) + " 联系电话不符合规则";
        }
        Pattern yearReg = Pattern.compile("^[1-9]{1}\\d{0,7}$");
        if ("".equals(incomeLastYear) || incomeLastYear == null) {
            remark = String.valueOf(remark) + " 上一年度销售收入为空";
        } else if (!yearReg.matcher(incomeLastYear).matches()) {
            remark = String.valueOf(remark) + " 上一年度销售收入不符合规则";
        }
        if ("".equals(salesThisYear) || salesThisYear == null) {
            remark = String.valueOf(remark) + " 本年度销售收入为空";
        } else if (!yearReg.matcher(salesThisYear).matches()) {
            remark = String.valueOf(remark) + " 本年度销售收入不符合规则";
        }
        if ("".equals(acceptTime) || acceptTime == null) {
            remark = String.valueOf(remark) + " 受理时间为空";
        } else {
            try {
                formatYMD.parse(acceptTime);
                acceptTime = String.valueOf(acceptTime.substring(0, 10)) + " 10:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused2) {
                remark = String.valueOf(remark) + " 受理时间格式不正确";
            }
        }
        if ("".equals(joinProduct) || joinProduct == null) {
            remark = String.valueOf(remark) + " 对接产品为空";
        }
        if ("".equals(openCheckTime) || openCheckTime == null) {
            remark = String.valueOf(remark) + " 启动审核操作时间为空";
        } else {
            try {
                formatYMD.parse(openCheckTime);
                openCheckTime = String.valueOf(openCheckTime.substring(0, 10)) + " 11:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused3) {
                remark = String.valueOf(remark) + " 启动审核操作时间格式不正确";
            }
        }
        if ("".equals(checkOperationTime) || checkOperationTime == null) {
            remark = String.valueOf(remark) + " 审核操作时间为空";
        } else {
            try {
                formatYMD.parse(checkOperationTime);
                checkOperationTime = String.valueOf(checkOperationTime.substring(0, 10)) + " 12:" + ((int) (Math.random() * 60.0d)) + ":" + ((int) (Math.random() * 60.0d));
            } catch (ParseException unused4) {
                remark = String.valueOf(remark) + " 审核操作时间格式不正确";
            }
        }
        Pattern reg = Pattern.compile("^\\d{1,5}(\\.\\d{1,6})?$");
        if ("".equals(creFinanceAmt) || creFinanceAmt == null) {
            remark = String.valueOf(remark) + " 审核融资金额为空";
        } else if (Double.parseDouble(creFinanceAmt) == 0.0d) {
            remark = String.valueOf(remark) + " 审核融资金额不符合规则";
        } else if (!reg.matcher(creFinanceAmt).matches()) {
            remark = String.valueOf(remark) + " 审核融资金额不符合规则";
        }
        if ("".equals(beginRate) || beginRate == null) {
            remark = String.valueOf(remark) + " 审核期望利率为空";
        } else if (!rate.matcher(beginRate).matches()) {
            remark = String.valueOf(remark) + " 审核期望利率不符合规则";
        }
        if ("".equals(financeDeadLine) || financeDeadLine == null) {
            remark = String.valueOf(remark) + " 审核融资期限为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d{0,2}$").matcher(financeDeadLine).matches()) {
            remark = String.valueOf(remark) + " 审核融资期限不符合规则";
        } else if (Integer.parseInt(financeDeadLine) > 360) {
            remark = String.valueOf(remark) + " 审核融资期限不能大于360";
        }
        if ("".equals(financeModelAudit) || financeModelAudit == null) {
            remark = String.valueOf(remark) + " 融资方式为空";
        }
        result.put("corName", corName);
        result.put("orgCode", orgCode);
        result.put("financeName", financeName);
        result.put("secendBraUserName", secendBraUserName);
        result.put("publishTime", publishTime);
        result.put("financeAmt", financeAmt);
        result.put("financeLimit", financeLimit);
        result.put("rateBegin", rateBegin);
        result.put("assureWay", assureWay);
        result.put("corContactName", corContactName);
        result.put("corContactTel", corContactTel);
        result.put("incomeLastYear", incomeLastYear);
        result.put("salesThisYear", salesThisYear);
        result.put("applyForProduct", applyForProduct);
        result.put("financePurpose", financePurpose);
        result.put("financeStation", financeStation);
        result.put("decomandRemark", decomandRemark);
        result.put("joinProduct", joinProduct);
        result.put("openCheckTime", openCheckTime);
        result.put("checkOperationTime", checkOperationTime);
        result.put("creFinanceAmt", creFinanceAmt);
        result.put("financeDeadLine", financeDeadLine);
        result.put("beginRate", beginRate);
        result.put("financeModelAudit", financeModelAudit);
        result.put("acceptTime", acceptTime);
        result.put("didRemark", remark);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            cell.setCellType(1);
                            result = cell.getRichStringCellValue().getString();
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
